@@ -562,19 +562,20 @@ def lazy_save(
         save_project_name: str,
         save_topic_name: str,
         save_env_file_name_datahub: str,
-        save_env_file_name_redis: str,
-        save_redis_db: int,
+        error_to_redis: bool = True,
+        save_env_file_name_redis: str = 'local.redis.env',
+        save_redis_db: int = 0,
         project_auto_create: bool = True,
         topic_auto_create: bool = True
 ):
     """
     此模块提供了存储json数据到DataHub的功能
     如果存储错误，将暂存在redis中，由错误处理进程继续处理
-
     :param data: 需要存储的数据，dict类型，单条存储
     :param save_project_name: 存储的目标project
     :param save_topic_name: 存储的目标topic
     :param save_env_file_name_datahub: datahub环境文件
+    :param error_to_redis: 是否存储到redis
     :param save_env_file_name_redis: redis环境文件
     :param save_redis_db: redis缓存数据库
     :param project_auto_create: 自动创建project
@@ -607,26 +608,34 @@ def lazy_save(
                 save_res['success'] = False
                 return save_res
             else:
+                if error_to_redis is True:
+                    fastredis.list_add_r(
+                        key=save_topic_name,
+                        value=json.dumps(data),
+                        env_file_name=save_env_file_name_redis,
+                        db=save_redis_db
+                    )
+                return save_res
+    except:
+        if error_to_redis is True:
+            try:
+                # 出错的转存到redis
                 fastredis.list_add_r(
                     key=save_topic_name,
                     value=json.dumps(data),
                     env_file_name=save_env_file_name_redis,
                     db=save_redis_db
                 )
-                return save_res
-    except:
-        try:
-            # 出错的转存到redis
-            fastredis.list_add_r(
-                key=save_topic_name,
-                value=json.dumps(data),
-                env_file_name=save_env_file_name_redis,
-                db=save_redis_db
-            )
-        except:
+            except:
+                save_res = {
+                    "code": 1,
+                    "msg": "failed",
+                    "success": False
+                }
+        else:
             save_res = {
                 "code": 1,
                 "msg": "failed",
                 "success": False
             }
-    return save_res
+        return save_res
